@@ -264,6 +264,8 @@ gssdp_resource_group_dispose (GObject *object)
                 g_object_unref (priv->client);
                 priv->client = NULL;
         }
+
+        G_OBJECT_CLASS (gssdp_resource_group_parent_class)->dispose (object);
 }
 
 static void
@@ -753,7 +755,7 @@ message_received_cb (GSSDPClient        *client,
                 return;
 
         /* Extract target */
-        target = soup_message_headers_get (headers, "ST");
+        target = soup_message_headers_get_one (headers, "ST");
         if (!target) {
                 g_warning ("Discovery request did not have an ST header");
 
@@ -764,7 +766,7 @@ message_received_cb (GSSDPClient        *client,
         want_all = (strcmp (target, GSSDP_ALL_RESOURCES) == 0);
 
         /* Extract MX */
-        mx_str = soup_message_headers_get (headers, "MX");
+        mx_str = soup_message_headers_get_one (headers, "MX");
         if (mx_str)
                 mx = atoi (mx_str);
         else
@@ -1061,7 +1063,12 @@ create_target_regex (const char *target, GError **error)
         char *version;
         char *version_pattern;
 
-        version_pattern = "[0-9]+";
+        if (strncmp (target, "urn:", 4) != 0) {
+                /* target is not a URN, No need to deal with version. */
+                return g_regex_new (target, 0, 0, error);
+        }
+
+        version_pattern = "[0-9]+$";
         /* Make sure we have enough room for version pattern */
         pattern = g_strndup (target,
                              strlen (target) + strlen (version_pattern));
